@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::IRC::Plugin::RTorrentStatus::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::RTorrentStatus::VERSION = '0.11';
+  $POE::Component::IRC::Plugin::RTorrentStatus::VERSION = '0.12';
 }
 
 use strict;
@@ -193,7 +193,7 @@ POE::Component::IRC::Plugin::RTorrentStatus - A PoCo-IRC plugin which prints RTo
 To quickly get an IRC bot with this plugin up and running, you can use
 L<App::Pocoirc|App::Pocoirc>:
 
- $ pocoirc -s irc.perl.org -j '#bots' -a 'RTorrentStatus{ "Channels": ["#bots"] }'
+ $ pocoirc -s irc.perl.org -j '#bots' -a 'RTorrentStatus{ "Channels": ["#bots"], "Torrent_log": "/tmp/torrentlog" }'
 
 Or use it in your code:
 
